@@ -1020,3 +1020,136 @@ test_that("logr38: log_warnings() accepts a null.", {
   expect_equal(length(res) == 1, TRUE)
   
 })
+
+test_that("logr39: logr.stdout option works as expected.", {
+  
+  tmp <- base_path
+  
+  options("logr.stdout" = TRUE)
+  
+  lf <- log_open(file.path(tmp, "test.log"))
+  log_print("Here is the first log message")
+  log_print(mtcars)
+  log_print("Here is a second log message")
+  
+  mp <- sub(".log", ".msg", lf, fixed = TRUE) 
+  log_close()
+  
+  ret <- file.exists(lf)
+  ret2 <- file.exists(mp)
+  
+  expect_equal(ret, FALSE)
+  expect_equal(ret2, FALSE)
+  
+  options("logr.stdout" = NULL)
+  
+})
+
+
+test_that("logr40: logr.stdout parameter works as expected.", {
+  
+  tmp <- base_path
+  
+
+  lf <- log_open(file.path(tmp, "test.log"), stdout = TRUE)
+  log_print("Here is the first log message")
+  log_print(mtcars)
+  log_print("Here is a second log message")
+  
+  mp <- sub(".log", ".msg", lf, fixed = TRUE) 
+  log_close()
+  
+  ret <- file.exists(lf)
+  ret2 <- file.exists(mp)
+  
+  expect_equal(ret, FALSE)
+  expect_equal(ret2, FALSE)
+  
+
+})
+
+
+
+test_that("logr41: the log_info() function works as expected.", {
+  
+  tmp <- base_path
+  
+  lf <- log_open(file.path(tmp, "test.log"))
+  log_print("Here is the first log message")
+
+  log_info("Here is a second log message")
+  
+  log_info(mtcars)
+  
+  mp <- sub(".log", ".msg", lf, fixed = TRUE) 
+  log_close()
+  
+  ret <- file.exists(lf)
+  ret2 <- file.exists(mp)
+  
+  expect_equal(ret, TRUE)
+  expect_equal(ret2, FALSE)
+  
+  
+})
+
+test_that("logr42: logr.linesize works as expected.", {
+  
+  tmp <- base_path
+  
+  options("logr.linesize" = 100)
+  
+  
+  lf <- log_open(file.path(tmp, "test.log"))
+  
+  str <- paste("Here is a a really long log line.", 
+               "I want to exceed 40 characters")
+  log_print(str)
+  
+  
+  
+  log_close()
+  
+  ret <- file.exists(lf)
+  
+  expect_equal(ret, TRUE)
+  
+  
+  readLines(lf)
+  
+  options("logr.linesize" = NULL)
+  
+})
+
+
+test_that("logr43: logdir with directory name works as expected.", {
+  
+  if (DEV) {
+    
+    tmp <- base_path
+  
+    
+    lf <- log_open(file.path(tmp, "test.log"), logdir = "myspdir")
+    
+    str <- paste("Here is a a really long log line.", 
+                 "I want to exceed 40 characters")
+    log_print(str)
+    
+    
+    
+    log_close()
+    
+    ret <- file.exists(lf)
+    
+    expect_equal(ret, TRUE)
+    
+    
+    readLines(lf)
+  
+
+  } else {
+    
+    expect_equal(TRUE, TRUE) 
+  }
+  
+})
